@@ -119,6 +119,55 @@ err:
 	return 1;
 }
 
+static int pre_read_file(struct thread_data *td, struct fio_file *f)
+{
+	int r, did_open = 0, old_runstate;
+	unsigned long long left;
+	unsigned int bs;
+	char *b;
+
+	if (!(f->flags & FIO_FILE_OPEN)) {
+		if (td->io_ops->open_file(td, f)) {
+			log_err("fio: cannot pre-read, failed to open file\n");
+			return 1;
+		}
+		did_open = 1;
+	}
+
+	old_runstate = td->runstate;
+	td_set_runstate(td, TD_PRE_READING);
+
+	bs = td->o.max_bs[DDIR_READ];
+	b = malloc(bs);
+	memset(b, 0, bs);
+
+	lseek(f->fd, f->file_offset, SEEK_SET);
+	left = f->io_size;
+
+	while (left && !td->terminate) {
+		if (bs > left)
+			bs = left;
+
+		r = read(f->fd, b, bs);
+
+		if (r == (int) bs) {
+			left -= bs;
+			continue;
+		} else {
+			printf("r=%d\n", r);
+			td_verror(td, EIO, "pre_read");
+			break;
+		}
+	}
+
+	td_set_runstate(td, old_runstate);
+
+	if (did_open)
+		td->io_ops->close_file(td, f);
+	free(b);
+	return 0;
+}
+
 static unsigned long long get_rand_file_size(struct thread_data *td)
 {
 	unsigned long long ret, sized;
@@ -572,6 +621,20 @@ err_offset:
 	return 1;
 }
 
+int pre_read_files(struct thread_data *td)
+{
+	struct fio_file *f;
+	unsigned int i;
+
+	dprint(FD_FILE, "pre_read files\n");
+
+	for_each_file(td, f, i) {
+		pre_read_file(td, f);
+	}
+
+	return 1;
+}
+
 int init_random_map(struct thread_data *td)
 {
 	unsigned long long blocks, num_maps;
