@@ -686,6 +686,7 @@ static struct fio_file *get_next_file_rr(struct thread_data *td, int goodf,
 			if (err) {
 				dprint(FD_FILE, "error %d on open of %s\n",
 					err, f->file_name);
+				f = NULL;
 				continue;
 			}
 			opened = 1;
@@ -838,7 +839,7 @@ struct io_u *get_io_u(struct thread_data *td)
 
 		f->last_pos = io_u->offset + io_u->buflen;
 
-		if (td->o.verify != VERIFY_NONE)
+		if (td->o.verify != VERIFY_NONE && io_u->ddir == DDIR_WRITE)
 			populate_verify_io_u(td, io_u);
 		else if (td->o.refill_buffers && io_u->ddir == DDIR_WRITE)
 			io_u_fill_buffer(td, io_u, io_u->xfer_buflen);
@@ -917,11 +918,11 @@ static void io_completed(struct thread_data *td, struct io_u *io_u,
 							&icd->time);
 
 			if (!td->o.disable_clat) {
-				add_clat_sample(td, idx, usec);
+				add_clat_sample(td, idx, usec, bytes);
 				io_u_mark_latency(td, usec);
 			}
 			if (!td->o.disable_bw)
-				add_bw_sample(td, idx, &icd->time);
+				add_bw_sample(td, idx, bytes, &icd->time);
 		}
 
 		if (td_write(td) && idx == DDIR_WRITE &&
@@ -1026,7 +1027,7 @@ void io_u_queued(struct thread_data *td, struct io_u *io_u)
 		unsigned long slat_time;
 
 		slat_time = utime_since(&io_u->start_time, &io_u->issue_time);
-		add_slat_sample(td, io_u->ddir, slat_time);
+		add_slat_sample(td, io_u->ddir, io_u->xfer_buflen, slat_time);
 	}
 }
 
